@@ -1,5 +1,4 @@
-# noinspection PyUnresolvedReferences,PyPackageRequirements
-from pytrain import PowerDistrict, GantryCrane, Switch
+from pytrain import GantryCrane, PowerDistrict, Switch
 
 g = GantryCrane(
     address=87,
@@ -7,25 +6,25 @@ g = GantryCrane(
     cab_right_pin=21,
     ro_left_pin=12,
     ro_right_pin=16,
-    bo_down_pin=8,
-    bo_up_pin=7,
-    mag_pin=23,
+    bo_down_pin=7,
+    bo_up_pin=8,
+    mag_pin=25,
     led_pin=24,
     cab_rotary_encoder=True,
 )
 
-pd13 = PowerDistrict(
-    13,
-    on_pin=17,
+pd14 = PowerDistrict(
+    14,
+    on_pin=23,
     off_pin=27,
     on_led_pin=22,
 )
 
-pd14 = PowerDistrict(
-    14,
-    on_pin=10,
-    off_pin=9,
-    on_led_pin=11,
+pd13 = PowerDistrict(
+    13,
+    on_pin=14,
+    off_pin=15,
+    on_led_pin=18,
 )
 
 sw1 = Switch(
