@@ -55,18 +55,22 @@ SERVICES = [
 
 PACKAGES = [
     "squeekboard",  # must be removed before labwc...
-    "libgl1",
-    "libegl1",
-    "mesa-libgallium",
     "bluez",
+    "chromium",
     "colord",
     "cups",
     "cups-browsed",
+    "cups-common",
     "dbus-org.freedesktop.ModemManager1",
     "firefox",
     "labwc",
+    "libcups",
+    "libcups2",
+    "libegl1",
+    "libgl1",
     "mailcap",
     "mailutils",
+    "mesa-libgallium",
     "modemmanager",
     "packagekit",
     "pipewire",
