@@ -85,7 +85,7 @@ class Base3Buffer(Thread):
         self._last_output_at = 0  # used to throttle writes to LCS Base3
         # data to send to the Base 3 is written into a queue, which is drained by the thread
         # created when this instance is started
-        self._send_queue: PollableQueue[bytes] = PollableQueue(buffer_size)
+        self._send_queue: PollableQueue = PollableQueue(buffer_size)
         self._send_cv = Condition()
         # we must send a keepalive packet to the Base 3 every few seconds to keep it
         # from closing the connection
