@@ -43,7 +43,7 @@ class D4Req(PdiReq, CompDataMixin):
             data_len = len(self._data)
             self._record_no = int.from_bytes(self._data[1:3], byteorder="little") if data_len > 2 else None
             self._action = D4Action(self._data[3]) if data_len > 3 else None
-            self._post_action = int.from_bytes(self._data[4:6]) if data_len > 5 else None
+            self._post_action = int.from_bytes(self._data[4:6], byteorder="little") if data_len > 5 else None
             self._suffix = int.from_bytes(self._data[8:10], byteorder="little") if data_len > 9 else None
             if self._action in {D4Action.QUERY, D4Action.UPDATE}:
                 self._start = self._data[6] if data_len > 6 else None
@@ -74,7 +74,7 @@ class D4Req(PdiReq, CompDataMixin):
                     self._tmcc_id = int(addr_str)
             elif self.action in {D4Action.FIRST_REC, D4Action.NEXT_REC}:
                 if self._action == D4Action.NEXT_REC:
-                    self._post_action = int.from_bytes(self._data[4:6]) if data_len > 5 else None
+                    self._post_action = int.from_bytes(self._data[4:6], byteorder="little") if data_len > 5 else None
                     self._start = 0
                     self._data_length = self._data[7] if data_len > 7 else None
                     self._next_record_no = (
@@ -183,7 +183,7 @@ class D4Req(PdiReq, CompDataMixin):
                 sf = ""
                 ts = f" {self.timestamp_str}"
                 di = f" Index: {hex(self.start)}" if self.start is not None else ""
-                dl = f" Length: {self.data_length}" if self.data_length is not None else ""
+                dl = f" Length: {hex(self.data_length)}" if self.data_length is not None else ""
                 tpl = BASE_MEMORY_ENGINE_READ_MAP.get(self.start, None)
                 if isinstance(tpl, CompDataHandler) and self._data_bytes and (self.data_length == tpl.length):
                     db = f" Data: {tpl.from_bytes(self._data_bytes)}"
@@ -191,7 +191,7 @@ class D4Req(PdiReq, CompDataMixin):
                     db = (
                         f" Data: {self._data_bytes.hex()}"
                         if self._data_bytes is not None and len(self._data_bytes) < 0xC0
-                        else " Data: None"
+                        else ""
                     )
             return f"{op}{tmcc}{rn}{ct}{sf}{di}{dl}{db}{ts} ({self.packet})"
         return super().payload
